Changelog
=========

0.0.5 (2022-04-01)
------------------

- the `to_nominal_attributes` method in the `sklearn.dataset` module requires now the
  `indices` parameter (incorrectly declared as optional); can parse a range string now as well
- fixed the `fit`, `set_params` and `__str__` methods fo the `MakeNominal` transformer
  (module `sklweka.preprocessing`)
- `WekaEstimator` (module `sklweka.classifiers`) and `WekaCluster` (module `sklweka.clusters`)
  now allow specifying which attributes to turn into nominal ones, which avoids having
  to manually convert the data (either as list with 0-based indices or range string with 1-based indices)
- `set_params` methods now ignore empty dictionaries


0.0.4 (2021-12-17)
------------------

- fixed sorting of labels in `to_instances` method in module `sklweka.dataset`
- redoing `X` when no class present in `load_arff` method (module `sklweka.dataset`)
- added `load_dataset` method in module `sklweka.dataset` that uses Weka to load the
  data before converting it into sklearn data structures (slower, but more flexible)


0.0.3 (2021-10-26)
------------------

- added support for generating data via Weka's data generators


0.0.2 (2021-04-12)
------------------

- requiring python-weka-wrapper3 version 0.2.1 at least in order to offer pickle support


0.0.1 (2021-03-28)
------------------

- initial release

